// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_SIM_FCVTMS_2D_TRACE_AARCH64_H_
#define VIXL_SIM_FCVTMS_2D_TRACE_AARCH64_H_

const uint64_t kExpected_NEON_fcvtms_2D[] = {
  0x00000000ffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x000000000000000a,
  0x000000000000000a, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffff6,
  0xfffffffffffffff6, 0x8000000000000000,
  0x8000000000000000, 0x8000000000000000,
  0x8000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x8000000000000000,
  0x8000000000000000, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000001,
  0x0000000000000001, 0x0000000000000000,
  0x0000000000000000, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x0000000000000000,
  0x0000000000000000, 0x8000000000000000,
  0x8000000000000000, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xfffffffffffffffe,
  0xfffffffffffffffe, 0xffffffffffffffff,
  0xffffffffffffffff, 0x8000000000000000,
  0x8000000000000000, 0x8000000000000000,
  0x8000000000000000, 0x8000000000000000,
  0x8000000000000000, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0xffffffffffffffff,
  0xffffffffffffffff, 0x0010000000000000,
  0x0010000000000000, 0x0010000000000001,
  0x0010000000000001, 0x0010000000000002,
  0x0010000000000002, 0x0010000000000003,
  0x0010000000000003, 0x001fedcba9876543,
  0x001fedcba9876543, 0x001ffffffffffffc,
  0x001ffffffffffffc, 0x001ffffffffffffd,
  0x001ffffffffffffd, 0x001ffffffffffffe,
  0x001ffffffffffffe, 0x001fffffffffffff,
  0x001fffffffffffff, 0x0008000000000000,
  0x0008000000000000, 0x0008000000000000,
  0x0008000000000000, 0x0008000000000001,
  0x0008000000000001, 0x0008000000000001,
  0x0008000000000001, 0x000ff6e5d4c3b2a1,
  0x000ff6e5d4c3b2a1, 0x000ffffffffffffe,
  0x000ffffffffffffe, 0x000ffffffffffffe,
  0x000ffffffffffffe, 0x000fffffffffffff,
  0x000fffffffffffff, 0x000fffffffffffff,
  0x000fffffffffffff, 0x0004000000000000,
  0x0004000000000000, 0x0004000000000000,
  0x0004000000000000, 0x0004000000000000,
  0x0004000000000000, 0x0004000000000000,
  0x0004000000000000, 0x0007fb72ea61d950,
  0x0007fb72ea61d950, 0x0007ffffffffffff,
  0x0007ffffffffffff, 0x0007ffffffffffff,
  0x0007ffffffffffff, 0x0007ffffffffffff,
  0x0007ffffffffffff, 0x0007ffffffffffff,
  0x0007ffffffffffff, 0xfff0000000000000,
  0xfff0000000000000, 0xffefffffffffffff,
  0xffefffffffffffff, 0xffeffffffffffffe,
  0xffeffffffffffffe, 0xffeffffffffffffd,
  0xffeffffffffffffd, 0xffe0123456789abd,
  0xffe0123456789abd, 0xffe0000000000004,
  0xffe0000000000004, 0xffe0000000000003,
  0xffe0000000000003, 0xffe0000000000002,
  0xffe0000000000002, 0xffe0000000000001,
  0xffe0000000000001, 0xfff8000000000000,
  0xfff8000000000000, 0xfff7ffffffffffff,
  0xfff7ffffffffffff, 0xfff7ffffffffffff,
  0xfff7ffffffffffff, 0xfff7fffffffffffe,
  0xfff7fffffffffffe, 0xfff0091a2b3c4d5e,
  0xfff0091a2b3c4d5e, 0xfff0000000000002,
  0xfff0000000000002, 0xfff0000000000001,
  0xfff0000000000001, 0xfff0000000000001,
  0xfff0000000000001, 0xfff0000000000000,
  0xfff0000000000000, 0xfffc000000000000,
  0xfffc000000000000, 0xfffbffffffffffff,
  0xfffbffffffffffff, 0xfffbffffffffffff,
  0xfffbffffffffffff, 0xfffbffffffffffff,
  0xfffbffffffffffff, 0xfff8048d159e26af,
  0xfff8048d159e26af, 0xfff8000000000001,
  0xfff8000000000001, 0xfff8000000000000,
  0xfff8000000000000, 0xfff8000000000000,
  0xfff8000000000000, 0xfff8000000000000,
  0xfff8000000000000, 0x8000000000000000,
  0x8000000000000000, 0x8000000000000000,
  0x8000000000000000, 0x8000000000000400,
  0x8000000000000400, 0x7ffffffffffffc00,
  0x7ffffffffffffc00, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0x7fffffffffffffff,
  0x7fffffffffffffff, 0xffffffff7ffffffe,
  0xffffffff7ffffffe, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff7fffffff,
  0xffffffff7fffffff, 0xffffffff80000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffff80000000, 0xffffffff80000000,
  0xffffffff80000000, 0x000000007ffffffd,
  0x000000007ffffffd, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007ffffffe,
  0x000000007ffffffe, 0x000000007fffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000007fffffff, 0x000000007fffffff,
  0x000000007fffffff, 0x00000000fffffffd,
  0x00000000fffffffd, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000fffffffe,
  0x00000000fffffffe, 0x00000000ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
  0x00000000ffffffff, 0x00000000ffffffff,
};
const unsigned kExpectedCount_NEON_fcvtms_2D = 207;

#endif  // VIXL_SIM_FCVTMS_2D_TRACE_AARCH64_H_
